require 'yaml'

require 'puppet/property'
require 'puppet/property/lxd'
require 'puppet/util/yaml'

class Puppet::Property::Lxd::Yaml < Puppet::Property
  validate do |value|
    if value.is_a?(String)
      begin
        Puppet::Util::Yaml.safe_load(value)
      rescue Puppet::Util::Yaml::YamlLoadError => e
        raise ArgumentError, "Invalid YAML for content: #{e} #{value.to_json}"
      end
    elsif value.is_a?(Hash)
      super(value)
    else
      raise ArgumentError, 'Content must be a Hash, or a YAML String'
    end
  end

  munge do |value|
    if value.is_a?(String)
      Puppet::Util::Yaml.safe_load(value)
    elsif value.is_a?(Hash)
      super(value)
    end
  end

  def insync?(is)
    @should.include?(is)
  end
end
