# frozen_string_literal: true

require 'puppet/provider/lxd'

module Puppet::Provider::Lxd::Profile
class Base < Puppet::Provider::Lxd::ResourceBase
  desc 'Manage profiles in LXD'

  def self.lxc_resource_type
    'profile'
  end

  def self.parse_resource(data)
    content = data.reject { |k, _| k =~ %r{^(used_by|name)$} }
    [{
      :name    => data['name'],
      :content => content,
    }]
  end

  mk_resource_methods \
    :content,
    :lxc_remote_name

  def create_resource
    self.class.lxc_create(self.name, remote_name: self.lxc_remote_name)
    put_resource
  end

  def put_resource
    self.class.lxc_put(
      self.name, self.content,
      remote_name: self.lxc_remote_name)
  end
end
end
