# frozen_string_literal: true

require 'uri'
require 'puppet/property/boolean'

Puppet::Type.newtype(:lxd_remote) do
  @doc = 'Manage LXC profile resource'

  ensurable do
    self.defaultvalues

    def retrieve
      provider.ensure
    end
  end

  newparam(:name, isnamevar: true) do
    desc 'Name of the resource'
  end

  newproperty(:address) do
    validate do |value|
      begin
        uri = URI.parse(value)
      rescue => detail
        raise ArgumentError, "Invalid address '#{uri}': #{detail}"
      end

      if uri.scheme != 'https'
        raise ArgumentError, "Address must be HTTPS: '#{uri}'"
      end
    end
  end

  newproperty(:auth_type) do
    newvalues(:tls, :candid, :oidc)
  end

  newproperty(:project) do
  end

  newproperty(:protocol) do
    newvalues(:simplestreams, :lxd)
    defaultto { 'simplestreams' }
  end

  newproperty(:public, parent: Puppet::Property::Boolean) do
    defaultto { false }
  end
end
