class lxd::configure () {
  include 'lxd'

  $preseed_content = $lxd::preseed_content
  $preseed_config = $lxd::preseed_config

  if $preseed_content and $preseed_config {
    fail("preseed_content and preseed_config are mutually exclusive")
  }

  $preseed_content_actual = if $preseed_content {
    $preseed_content
  } elsif $preseed_config {
    stdlib::to_yaml($preseed_config)
  } else {
    fail('preseed_content or preseed_config required')
  }

  file { 'lxd-preseed':
    path    => "${lxd::var_path}/puppet-preseed.yaml",
    owner   => 'root',
    group   => 'root',
    mode    => '0640',
    notify  => Exec['lxd-init'],
    content => $preseed_content_actual,
  }

  exec { 'lxd-configure-subuids':
    command => 'usermod --add-subuids 1000000-1065535 root',
    unless  => "grep -q '^root:1000000:' /etc/subuid",
    path    => "/usr/local/bin:/usr/local/sbin:/usr/bin:/usr/sbin:/bin:/sbin",
    notify  => Service[$lxd::service_name],
  }

  exec { 'lxd-configure-subgids':
    command => 'usermod --add-subgids 1000000-1065535 root',
    unless  => "grep -q '^root:1000000:' /etc/subgid",
    path    => "/usr/local/bin:/usr/local/sbin:/usr/bin:/usr/sbin:/bin:/sbin",
    notify  => Service[$lxd::service_name],
  }

  if $facts['os']['family'] == 'RedHat' {
    ensure_resource('class', 'selinux', {
      mode => 'permissive',
      type => 'targeted',
    })
    Class['selinux'] -> Service[$lxd::service_name]
  }

  service { $lxd::service_name:
    ensure => 'running',
    enable => true,
  }

  exec { 'lxd-init':
    command     => @("EOF"),
${lxd::command} ${lxd::init_command.join(' ')} --preseed < '${lxd::var_path}/puppet-preseed.yaml'
EOF
    require     => Service[$lxd::service_name],
    refreshonly => true,
    path        => "/usr/local/bin:/usr/local/sbin:/usr/bin:/usr/sbin:/bin:/sbin",
  }
}
